@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -346,7 +346,7 @@ class IdentityAwareProxyAdminServiceClient(
 
     def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -358,7 +358,7 @@ class IdentityAwareProxyAdminServiceClient(
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.SetIamPolicyRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -453,7 +453,7 @@ class IdentityAwareProxyAdminServiceClient(
 
     def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -465,7 +465,7 @@ class IdentityAwareProxyAdminServiceClient(
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.GetIamPolicyRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -560,7 +560,7 @@ class IdentityAwareProxyAdminServiceClient(
 
     def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -572,7 +572,7 @@ class IdentityAwareProxyAdminServiceClient(
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -612,7 +612,7 @@ class IdentityAwareProxyAdminServiceClient(
 
     def get_iap_settings(
         self,
-        request: service.GetIapSettingsRequest = None,
+        request: Union[service.GetIapSettingsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -622,7 +622,7 @@ class IdentityAwareProxyAdminServiceClient(
         resource.
 
         Args:
-            request (google.cloud.iap_v1.types.GetIapSettingsRequest):
+            request (Union[google.cloud.iap_v1.types.GetIapSettingsRequest, dict]):
                 The request object. The request sent to GetIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -660,7 +660,7 @@ class IdentityAwareProxyAdminServiceClient(
 
     def update_iap_settings(
         self,
-        request: service.UpdateIapSettingsRequest = None,
+        request: Union[service.UpdateIapSettingsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -670,7 +670,7 @@ class IdentityAwareProxyAdminServiceClient(
         It replaces all fields unless the ``update_mask`` is set.
 
         Args:
-            request (google.cloud.iap_v1.types.UpdateIapSettingsRequest):
+            request (Union[google.cloud.iap_v1.types.UpdateIapSettingsRequest, dict]):
                 The request object. The request sent to
                 UpdateIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
