@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -348,7 +348,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def list_brands(
         self,
-        request: service.ListBrandsRequest = None,
+        request: Union[service.ListBrandsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -357,7 +357,7 @@ class IdentityAwareProxyOAuthServiceClient(
         r"""Lists the existing brands for the project.
 
         Args:
-            request (google.cloud.iap_v1.types.ListBrandsRequest):
+            request (Union[google.cloud.iap_v1.types.ListBrandsRequest, dict]):
                 The request object. The request sent to ListBrands.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -395,7 +395,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def create_brand(
         self,
-        request: service.CreateBrandRequest = None,
+        request: Union[service.CreateBrandRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -413,7 +413,7 @@ class IdentityAwareProxyOAuthServiceClient(
         by the caller.
 
         Args:
-            request (google.cloud.iap_v1.types.CreateBrandRequest):
+            request (Union[google.cloud.iap_v1.types.CreateBrandRequest, dict]):
                 The request object. The request sent to CreateBrand.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -454,7 +454,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def get_brand(
         self,
-        request: service.GetBrandRequest = None,
+        request: Union[service.GetBrandRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -463,7 +463,7 @@ class IdentityAwareProxyOAuthServiceClient(
         r"""Retrieves the OAuth brand of the project.
 
         Args:
-            request (google.cloud.iap_v1.types.GetBrandRequest):
+            request (Union[google.cloud.iap_v1.types.GetBrandRequest, dict]):
                 The request object. The request sent to GetBrand.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -504,7 +504,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def create_identity_aware_proxy_client(
         self,
-        request: service.CreateIdentityAwareProxyClientRequest = None,
+        request: Union[service.CreateIdentityAwareProxyClientRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -516,7 +516,7 @@ class IdentityAwareProxyOAuthServiceClient(
         use.
 
         Args:
-            request (google.cloud.iap_v1.types.CreateIdentityAwareProxyClientRequest):
+            request (Union[google.cloud.iap_v1.types.CreateIdentityAwareProxyClientRequest, dict]):
                 The request object. The request sent to
                 CreateIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -559,7 +559,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def list_identity_aware_proxy_clients(
         self,
-        request: service.ListIdentityAwareProxyClientsRequest = None,
+        request: Union[service.ListIdentityAwareProxyClientsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -568,7 +568,7 @@ class IdentityAwareProxyOAuthServiceClient(
         r"""Lists the existing clients for the brand.
 
         Args:
-            request (google.cloud.iap_v1.types.ListIdentityAwareProxyClientsRequest):
+            request (Union[google.cloud.iap_v1.types.ListIdentityAwareProxyClientsRequest, dict]):
                 The request object. The request sent to
                 ListIdentityAwareProxyClients.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -620,7 +620,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def get_identity_aware_proxy_client(
         self,
-        request: service.GetIdentityAwareProxyClientRequest = None,
+        request: Union[service.GetIdentityAwareProxyClientRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -630,7 +630,7 @@ class IdentityAwareProxyOAuthServiceClient(
         Requires that the client is owned by IAP.
 
         Args:
-            request (google.cloud.iap_v1.types.GetIdentityAwareProxyClientRequest):
+            request (Union[google.cloud.iap_v1.types.GetIdentityAwareProxyClientRequest, dict]):
                 The request object. The request sent to
                 GetIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -673,7 +673,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def reset_identity_aware_proxy_client_secret(
         self,
-        request: service.ResetIdentityAwareProxyClientSecretRequest = None,
+        request: Union[service.ResetIdentityAwareProxyClientSecretRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -684,7 +684,7 @@ class IdentityAwareProxyOAuthServiceClient(
         that the client is owned by IAP.
 
         Args:
-            request (google.cloud.iap_v1.types.ResetIdentityAwareProxyClientSecretRequest):
+            request (Union[google.cloud.iap_v1.types.ResetIdentityAwareProxyClientSecretRequest, dict]):
                 The request object. The request sent to
                 ResetIdentityAwareProxyClientSecret.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -727,7 +727,7 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def delete_identity_aware_proxy_client(
         self,
-        request: service.DeleteIdentityAwareProxyClientRequest = None,
+        request: Union[service.DeleteIdentityAwareProxyClientRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -739,7 +739,7 @@ class IdentityAwareProxyOAuthServiceClient(
         after tests. Requires that the client is owned by IAP.
 
         Args:
-            request (google.cloud.iap_v1.types.DeleteIdentityAwareProxyClientRequest):
+            request (Union[google.cloud.iap_v1.types.DeleteIdentityAwareProxyClientRequest, dict]):
                 The request object. The request sent to
                 DeleteIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
